@@ -11,25 +11,26 @@
 #'
 #' # rstanarm models
 #' # -----------------------------------------------
-#' library(rstanarm)
-#' model <- rstanarm::stan_glm(mpg ~ wt + cyl, data = mtcars)
-#' describe_prior(model)
+#' if (require("rstanarm")) {
+#'   model <- rstanarm::stan_glm(mpg ~ wt + cyl, data = mtcars)
+#'   describe_prior(model)
+#' }
 #'
 #' # brms models
 #' # -----------------------------------------------
-#' library(brms)
-#' model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
-#' describe_prior(model)
+#' if (require("brms")) {
+#'   model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
+#'   describe_prior(model)
+#' }
 #'
 #' # BayesFactor objects
 #' # -----------------------------------------------
-#' library(BayesFactor)
-#' bf <- ttestBF(x = rnorm(100, 1, 1))
-#' describe_prior(bf)
+#' if (require("BayesFactor")) {
+#'   bf <- ttestBF(x = rnorm(100, 1, 1))
+#'   describe_prior(bf)
+#' }
 #' }
-#'
 #' @importFrom insight get_priors
-#'
 #' @export
 describe_prior <- function(model, ...) {
   UseMethod("describe_prior")
@@ -64,6 +65,9 @@ describe_prior.stanreg <- .describe_prior
 #' @export
 describe_prior.brmsfit <- .describe_prior
 
+#' @export
+describe_prior.bcplm <- .describe_prior
+
 
 
 
