@@ -97,7 +97,7 @@
 #' equivalence_test(model)
 #' equivalence_test(model, ci = c(.50, .99))
 #'
-#' ibrary(BayesFactor)
+#' library(BayesFactor)
 #' bf <- ttestBF(x = rnorm(100, 1, 1))
 #' equivalence_test(bf)
 #' equivalence_test(bf, ci = c(.50, .99))
@@ -169,7 +169,7 @@ equivalence_test.data.frame <- function(x, range = "default", ci = .89, verbose
   )
   row.names(out) <- NULL
 
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   class(out) <- unique(c("equivalence_test", "see_equivalence_test", class(out)))
 
   out
@@ -184,7 +184,7 @@ equivalence_test.emmGrid <- function(x, range = "default", ci = .89, verbose = T
   xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
 
   out <- equivalence_test(xdf, range = range, ci = ci, verbose = verbose, ...)
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
@@ -193,6 +193,7 @@ equivalence_test.emmGrid <- function(x, range = "default", ci = .89, verbose = T
 #' @export
 equivalence_test.BFBayesFactor <- function(x, range = "default", ci = .89, verbose = TRUE, ...) {
   out <- equivalence_test(insight::get_parameters(x), range = range, ci = ci, verbose = verbose, ...)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
@@ -201,7 +202,7 @@ equivalence_test.BFBayesFactor <- function(x, range = "default", ci = .89, verbo
 
 #' @importFrom stats sd
 #' @keywords internal
-.equivalence_test_models <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE) {
+.equivalence_test_models <- function(x, range = "default", ci = .89, effects = "fixed", component = "conditional", parameters = NULL, verbose = TRUE) {
   if (all(range == "default")) {
     range <- rope_range(x)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
@@ -209,9 +210,10 @@ equivalence_test.BFBayesFactor <- function(x, range = "default", ci = .89, verbo
   }
 
   if (verbose) .check_multicollinearity(x)
+  params <- insight::get_parameters(x, component = component, effects = effects, parameters = parameters)
 
   l <- sapply(
-    insight::get_parameters(x, component = "conditional", parameters = parameters),
+    params,
     equivalence_test,
     range = range,
     ci = ci,
@@ -233,33 +235,55 @@ equivalence_test.BFBayesFactor <- function(x, range = "default", ci = .89, verbo
 
 #' @rdname equivalence_test
 #' @export
-equivalence_test.stanreg <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
-  out <- .equivalence_test_models(x, range, ci, parameters, verbose)
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
-  out
-}
+equivalence_test.stanreg <- function(x, range = "default", ci = .89, effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
+  effects <- match.arg(effects)
 
+  out <- .equivalence_test_models(x, range, ci, effects, component = "conditional", parameters, verbose)
+  out <- merge(out, insight::clean_parameters(x)[, c("Parameter", "Effects", "Cleaned_Parameter")], by = "Parameter", sort = FALSE)
 
-#' @export
-equivalence_test.sim.merMod <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
-  out <- .equivalence_test_models(x, range, ci, parameters, verbose = FALSE)
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
-  out
-}
-
-
-#' @export
-equivalence_test.sim <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
-  out <- .equivalence_test_models(x, range, ci, parameters, verbose = FALSE)
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  class(out) <- unique(c("equivalence_test", "see_equivalence_test", class(out)))
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
 
 
 #' @rdname equivalence_test
 #' @export
-equivalence_test.brmsfit <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
-  out <- .equivalence_test_models(x, range, ci, parameters, verbose)
-  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+equivalence_test.brmsfit <- function(x, range = "default", ci = .89, effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, verbose = TRUE, ...) {
+  effects <- match.arg(effects)
+  component <- match.arg(component)
+
+  out <- .equivalence_test_models(x, range, ci, effects, component, parameters, verbose)
+  out <- merge(out, insight::clean_parameters(x)[, c("Parameter", "Effects", "Component", "Cleaned_Parameter")], by = "Parameter", sort = FALSE)
+
+  class(out) <- unique(c("equivalence_test", "see_equivalence_test", class(out)))
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  out
+}
+
+
+#' @export
+equivalence_test.sim.merMod <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
+  out <- .equivalence_test_models(x, range, ci, effects = "fixed", component = "conditional", parameters, verbose = FALSE)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  out
+}
+
+#' @export
+equivalence_test.sim <- equivalence_test.sim.merMod
+
+
+#' @export
+equivalence_test.mcmc <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
+  out <- .equivalence_test_models(as.data.frame(x), range, ci, effects = "fixed", component = "conditional", parameters, verbose = FALSE)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  out
+}
+
+
+#' @export
+equivalence_test.bcplm <- function(x, range = "default", ci = .89, parameters = NULL, verbose = TRUE, ...) {
+  out <- .equivalence_test_models(insight::get_parameters(x), range, ci, effects = "fixed", component = "conditional", parameters, verbose = FALSE)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
