@@ -2,8 +2,9 @@
 #'
 #' Compute the \strong{Highest Density Interval (HDI)} of posterior distributions. All points within this interval have a higher probability density than points outside the interval. The HDI can be used in the context of uncertainty characterisation of posterior distributions as \strong{Credible Interval (CI)}.
 #'
-#' @param x Vector representing a posterior distribution. Can also be a
-#'   \code{stanreg}, \code{brmsfit} or a \code{BayesFactor} model.
+#' @param x Vector representing a posterior distribution, or a data frame of such
+#'   vectors. Can also be a Bayesian model (\code{stanreg}, \code{brmsfit},
+#'   \code{MCMCglmm}, \code{mcmc} or \code{bcplm}) or a \code{BayesFactor} model.
 #' @param ci Value or vector of probability of the (credible) interval - CI (between 0 and 1)
 #'   to be estimated. Default to \code{.89} (89\%).
 #' @param effects Should results for fixed effects, random effects or both be returned?
@@ -64,6 +65,7 @@
 #' hdi(df)
 #' hdi(df, ci = c(.80, .90, .95))
 #'
+#' \dontrun{
 #' library(rstanarm)
 #' model <- stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200, refresh = 0)
 #' hdi(model)
@@ -71,7 +73,7 @@
 #'
 #' library(emmeans)
 #' hdi(emtrends(model, ~1, "wt"))
-#' \dontrun{
+#'
 #' library(brms)
 #' model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
 #' hdi(model)
@@ -142,6 +144,16 @@ hdi.mcmc <- function(x, ci = .89, verbose = TRUE, ...) {
 
 
 
+#' @export
+hdi.bcplm <- function(x, ci = .89, verbose = TRUE, ...) {
+  d <- insight::get_parameters(x)
+  dat <- .compute_interval_dataframe(x = d, ci = ci, verbose = verbose, fun = "hdi")
+  attr(dat, "data") <- .safe_deparse(substitute(x))
+  dat
+}
+
+
+
 #' @rdname hdi
 #' @export
 hdi.sim.merMod <- function(x, ci = .89, effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
