@@ -30,14 +30,17 @@
 #' df <- data.frame(replicate(4, rnorm(100)))
 #' p_significance(df)
 #'
+#' \dontrun{
 #' # rstanarm models
 #' # -----------------------------------------------
-#' library(rstanarm)
-#' model <- rstanarm::stan_glm(mpg ~ wt + cyl,
-#'   data = mtcars,
-#'   chains = 2, refresh = 0
-#' )
-#' p_significance(model)
+#' if (require("rstanarm")) {
+#'   model <- rstanarm::stan_glm(mpg ~ wt + cyl,
+#'     data = mtcars,
+#'     chains = 2, refresh = 0
+#'   )
+#'   p_significance(model)
+#' }
+#' }
 #' @export
 p_significance <- function(x, ...) {
   UseMethod("p_significance")
@@ -118,6 +121,12 @@ p_significance.mcmc <- function(x, threshold = "default", ...) {
 }
 
 
+#' @export
+p_significance.bcplm <- function(x, threshold = "default", ...) {
+  p_significance(insight::get_parameters(x), threshold = threshold, ...)
+}
+
+
 #' @rdname p_significance
 #' @export
 p_significance.emmGrid <- function(x, threshold = "default", ...) {
